Share and Enjoy
===============

This package would not have been possible without the contribution of the following people:

- Héctor Velarde
- Font Awesome (`icons <http://fontawesome.io/>`_)

You can find an updated list of package contributors on `GitHub <https://github.com/collective/collective.behavior.amp/contributors>`_.
